@@ -1,5 +1,6 @@
 import os
 import sys
+import tempfile
 import subprocess
 
 from . import rerun
@@ -22,8 +23,9 @@ def daemon_mode(args=None, module_name=None, debug=False):
         child_env.update({'__DAEMON__': '1'})
         subprocess.Popen(
             invocation,
-            stdout=sys.stdout,
-            stderr=sys.stderr,
+            stdin=subprocess.DEVNULL,
+            stdout=tempfile.TemporaryFile(),
+            stderr=tempfile.TemporaryFile(),
             creationflags=subprocess.CREATE_NEW_CONSOLE if debug else subprocess.DETACHED_PROCESS,
             env=child_env
         )
