@@ -1,10 +1,11 @@
 import os
 import sys
 import shlex
+import pathlib
 
 MODES = {
-    'NORMAL_MODE': lambda args=None: '{} {} {}'.format(sys.executable, sys.argv[0], shlex.join(sys.argv[1:] if args is None else args)),
-    'MODULE_MODE': lambda args=None: '{} -m {}'.format(sys.executable, sys.argv[0], shlex.join(sys.argv[1:] if args is None else args)),
+    'NORMAL_MODE': lambda args=None: '{} {} {}'.format(sys.executable, pathlib.Path(sys.argv[0]).absolute(), shlex.join(sys.argv[1:] if args is None else args)),
+    'MODULE_MODE': lambda args=None: '{} -m {}'.format(sys.executable, pathlib.Path(sys.argv[0]).absolute(), shlex.join(sys.argv[1:] if args is None else args)),
     'PYINSTALLER_MODE': lambda args=None: '{} {}'.format(sys.executable, shlex.join(sys.argv[1:] if args is None else args)),
 }
 
